@@ -3,7 +3,7 @@ package Text::Xslate::PP;
 use 5.008_001;
 use strict;
 
-our $VERSION = '1.5025';
+our $VERSION = '1.6001';
 
 BEGIN{
     $ENV{XSLATE} = ($ENV{XSLATE} || '') . '[pp]';
@@ -347,6 +347,9 @@ sub _assemble {
 
     sub is_array_ref { ref($_[0]) eq 'ARRAY' }
     sub is_hash_ref  { ref($_[0]) eq 'HASH'  }
+    sub is_code_ref  { ref($_[0]) eq 'CODE'  }
+
+    sub merge_hash { +{ %{ $_[0] }, %{ $_[1] } } }
 }
 
 #
@@ -569,6 +572,7 @@ sub tx_execute {
     local $st->{sb};
     local $st->{output} = '';
     $st->{code}->[0]->{ exec_code }->( $st );
+    @{$st->{frame}->[-1]} = Text::Xslate::PP::TXframe_START_LVAR - 1;
     return $st->{output};
 }
 
@@ -643,7 +647,7 @@ Text::Xslate::PP - Yet another Text::Xslate runtime in pure Perl
 
 =head1 VERSION
 
-This document describes Text::Xslate::PP version 1.5025.
+This document describes Text::Xslate::PP version 1.6001.
 
 =head1 DESCRIPTION
 
